@@ -3,6 +3,7 @@ __all__ = [
     "MarkdownSerializer",
     "ExternalFilesManager",
     "SerializedFile",
+    "snapshot_serialization_filter",
     "EXTENSION_HIGHLIGHTING",
 ]
 
@@ -41,6 +42,11 @@ EXTENSION_HIGHLIGHTING = {
 }
 
 
+def snapshot_serialization_filter(pack: Union[DataPack, ResourcePack]) -> bool:
+    """Filter that selects non-empty packs and empty packs with modified pack.mcmeta."""
+    return bool(pack or pack.mcmeta != type(pack)().mcmeta)
+
+
 @dataclass
 class ExternalFilesManager:
     """Class responsible for saving external files."""
@@ -292,6 +298,9 @@ class MarkdownSerializer:
             )
 
         for name, namespace in pack.items():
+            if not namespace:
+                continue
+
             yield f"\n### {name}"
 
             for path, file_instance in namespace.extra.items():
